@@ -15,6 +15,10 @@ import sys
 
 import click
 
+from app.schema_graphql import get_schema_for_provider
+from shaystack import HaystackInterface
+from shaystack.providers import get_provider
+
 try:
     # noinspection PyUnresolvedReferences
     from flask import Blueprint
@@ -23,41 +27,15 @@ try:
 except ImportError:
     os.abort()
 
-import graphene
-from .graphql_model import ReadHaystack
-
 log = logging.getLogger("shaystack")
 
 
-class Query(graphene.ObjectType):
-    """GraphQL haystack query. To integrate the haystack Graphql API with other
-    GraphQL API, see `aws appsync` .
-    """
-
-    class Meta:  # pylint: disable=missing-class-docstring
-        description = "Root for haystack api"
-
-    haystack = graphene.Field(graphene.NonNull(ReadHaystack))
-
-    # noinspection PyUnusedLocal
-    @staticmethod
-    def resolve_haystack(parent, info):
-        """
-        Args:
-            parent:
-            info:
-        """
-        return ReadHaystack()
-
-
 # noinspection PyTypeChecker
-schema = graphene.Schema(query=Query)
-
-def create_graphql_bp() -> Blueprint:
+def create_graphql_bp(provider: HaystackInterface) -> Blueprint:
+    schema = get_schema_for_provider(provider)
     graphql_blueprint = Blueprint('graphql',
                                   __name__,
                                   url_prefix='/graphql')
-
     graphql_blueprint.add_url_rule('',
                                    view_func=GraphQLView.as_view(
                                        'graphql',
@@ -67,10 +45,12 @@ def create_graphql_bp() -> Blueprint:
     return graphql_blueprint
 
 
-def _dump_haystack_schema() -> None:
+def _dump_haystack_schema(provider) -> None:
     """Print haystack schema to insert in another global schema."""
     # Print only haystack schema
     from graphql.utils import schema_printer  # pylint: disable=import-outside-toplevel
+    schema = get_schema_for_provider(provider)
+
     print(schema_printer.print_schema(schema))
 
 
@@ -80,7 +60,9 @@ def main() -> int:
     `GRAPHQL_SCHEMA=app/haystack_schema.json python app/blueprint_graphql.py`
     >partial_gql.graphql
     """
-    _dump_haystack_schema()
+    provider_name = os.environ.get("HAYSTACK_PROVIDER", "shaystack.providers.db")
+    provider = get_provider(provider_name, os.environ)
+    _dump_haystack_schema(provider)
     return 0
 
 
