@@ -38,7 +38,8 @@ __all__ = ['Grid', 'dump', 'parse', 'dump_scalar', 'parse_scalar', 'parse_filter
            'MetadataObject', 'unit_reg', 'zoneinfo',
            'HaystackType', 'Entity',
            'Coordinate', 'Uri', 'Bin', 'XStr', 'Quantity', 'MARKER', 'NA', 'REMOVE', 'Ref',
-           'MODE', 'MODE_JSON', 'MODE_HAYSON', 'MODE_ZINC', 'MODE_TRIO', 'MODE_CSV', 'suffix_to_mode', 'mode_to_suffix',
+           'MODE', 'MODE_JSON', 'MODE_HAYSON', 'MODE_ZINC', 'MODE_TRIO', 'MODE_CSV',
+           'suffix_to_mode', 'mode_to_suffix',
            'parse_hs_datetime_format',
            'VER_2_0', 'VER_3_0', 'LATEST_VER', 'Version',
 
