@@ -32,7 +32,7 @@ class DBCursor(Protocol):
 
     def close(self) -> None: ...
 
-    def __iter__(self) -> Iterator[List]: ...
+    def __iter__(self) -> Iterator[List]: return [].__iter__()
 
 
 class DBConnection(Protocol):  # pylint: disable=multiple-statements,no-self-use, missing-class-docstring
